@@ -22,12 +22,13 @@ fn main() {
         .get_matches();
     let url = matches.value_of("url").unwrap();
     let client = reqwest::blocking::Client::builder()
-        .timeout(Duration::new(30, 0))
+        .timeout(Duration::new(10, 0))
         .gzip(true)
         .build()
         .expect("Couldn't create reqwest HTTP client");
     let xml = client.get(url)
-        .header("Accept", "application/dash+xml")
+        .header("Accept", "application/dash+xml,video/vnd.mpeg.dash.mpd")
+        .header("Accept-language", "en-US,en")
         .send()
         .expect("requesting DASH MPD")
         .text()
@@ -39,24 +40,36 @@ fn main() {
     // commercial streaming services often include separate audio tracks for the different dubbed
     // languages available, but audio may also be included with the video track.
     if let Some(audio_adaptation) = period.adaptations.as_ref().and_then(|a| a.iter().find(is_audio_adaptation)) {
-        for representation in audio_adaptation.representations.iter() {
-            // Here we see some of the fun of dealing with the MPD format: the codec can be
-            // specified on the <Representation> element, or on the relevant <AdaptationSet>
-            // element, or not at all.
-            let codec = representation.codecs.as_ref()
-                .unwrap_or_else(|| audio_adaptation.codecs.as_ref()
-                                .unwrap_or(&unspecified));
-            println!("Audio stream with codec {}, bandwidth {}", codec, representation.bandwidth);
+        if let Some(reps) = &audio_adaptation.representations {
+            for representation in reps.iter() {
+                // Here we see some of the fun of dealing with the MPD format: the codec can be
+                // specified on the <Representation> element, or on the relevant <AdaptationSet>
+                // element, or not at all.
+                let codec = representation.codecs.as_ref()
+                    .unwrap_or_else(|| audio_adaptation.codecs.as_ref()
+                                    .unwrap_or(&unspecified));
+                let bw = match representation.bandwidth {
+                    Some(b) => b.to_string(),
+                    None => "<unspecified>".to_string(),
+                };
+                println!("Audio stream with codec {}, bandwidth {}", codec, bw);
+            }
         }
     }
 
     // Show video tracks with the codecs and available bitrates
     if let Some(video_adaptation) = period.adaptations.as_ref().and_then(|a| a.iter().find(is_video_adaptation)) {
-        for representation in video_adaptation.representations.iter() {
-            let codec = representation.codecs.as_ref()
-                .unwrap_or_else(|| video_adaptation.codecs.as_ref()
-                                .unwrap_or(&unspecified));
-            println!("Video stream with codec {}, bandwidth {}", codec, representation.bandwidth);
+        if let Some(reps) = &video_adaptation.representations {
+            for representation in reps.iter() {
+                let codec = representation.codecs.as_ref()
+                    .unwrap_or_else(|| video_adaptation.codecs.as_ref()
+                                    .unwrap_or(&unspecified));
+                let bw = match representation.bandwidth {
+                    Some(b) => b.to_string(),
+                    None => "<unspecified>".to_string(),
+                };
+                println!("Video stream with codec {}, bandwidth {}", codec, bw);
+            }
         }
     }
 }
